@@ -40,7 +40,7 @@
 
 #define DBG(a,b) if(_dbg>=(a))b
 
-static int _dbg = 0;
+int _dbg = 0;
 static CORBA_Environment ev;
 static Accessibility_Registry registry = CORBA_OBJECT_NIL;
 static Accessibility_DeviceEventController device_event_controller = CORBA_OBJECT_NIL;
@@ -1016,7 +1016,7 @@ spi_atk_tidy_windows (void)
         {
           spi_atk_emit_eventv (G_OBJECT (child), 0, 0, &any, "window:deactivate");
         }
-      g_free (stateset);
+      g_object_unref (stateset);
 
       spi_atk_emit_eventv (G_OBJECT (child), 0, 0, &any, "window:destroy");
       g_object_unref (child);
